@@ -66,6 +66,7 @@ protected:
 	Keydata head, args;
 	const char *tsid;
 	const char *voice;
+	Audio::Level level;
 
 public:
 	result_t result;
@@ -121,6 +122,14 @@ public:
 	inline void setVoice(const char *v)
 		{voice = v;};
 
+	/**
+	 * Set the effective audio level for tones...
+	 *
+	 * @param level to set.
+	 */
+	inline void setLevel(Audio::Level l)
+		{level = l;};
+
 	/**
 	 * Hangup running session...
 	 */
@@ -184,6 +193,18 @@ public:
 	 */
 	result_t speak(const char *format, ...);
 
+	/**
+	 * Play a tone.
+	 *
+	 * @return result code.
+	 * @param name of tone to play.
+	 * @param duration for tone.
+	 * @param audio level of tone.
+	 */
+	result_t playTone(const char *name, timeout_t duration = 0, unsigned level = 0);
+	result_t playSingleTone(short f1, timeout_t duration, unsigned level = 0);
+	result_t playDualTone(short f1, short f2, timeout_t duration, unsigned level = 0);
+
 	/**
 	 * Record an audio file to a specified offset.
 	 *
@@ -232,7 +253,7 @@ public:
 	 * @param size of input buffer.
 	 * @param timeout for input.
 	 */
-	result_t getline(char *buffer, unsigned size, timeout_t timeout);
+	result_t readInput(char *buffer, unsigned size, timeout_t timeout);
 
 	/**
 	 * Read a single key of input.
@@ -240,7 +261,7 @@ public:
 	 * @return key input or 0.
 	 * @param timeout for read.
 	 */
-	char inkey(timeout_t timeout);
+	char readKey(timeout_t timeout);
 
 	result_t sizeSym(const char *id, unsigned size);
 	result_t addSym(const char *id, const char *value);
@@ -261,6 +282,9 @@ protected:
 	void sysReplay(const char *tsid, char *token);
 	void sysFlush(const char *tsid);
 	void sysWait(const char *tsid, char *token);
+	void sysTone(const char *tsid, char *token);
+	void sysSTone(const char *tsid, char *token);
+	void sysDTone(const char *tsid, char *token);
 	void sysPrompt(const char *tsid, const char *voice, const char *text);
 	void sysInput(const char *tsid, char *token);
 	void sysHangup(const char *tsid);
