@@ -1136,10 +1136,13 @@ const char *BayonneSession::getAudio(bool live)
 
 	clrAudio();
 
-	if(!cp)
+	if(ext && !*ext)
+		ext = NULL;
+
+	if(!cp || !*cp)
 		cp = ext;
 
-	if(cp)
+	if(cp && *cp)
 	{
 		audio.encoding = Audio::getEncoding(cp); 
 
@@ -1150,7 +1153,7 @@ const char *BayonneSession::getAudio(bool live)
 		audio.encoding = Audio::unknownEncoding;
 
 	cp = getKeyword("framing");
-	if(cp)
+	if(cp && *cp)
 		audio.framing = atoi(cp);
 	else
 		audio.framing = 0;
@@ -1160,6 +1163,9 @@ const char *BayonneSession::getAudio(bool live)
 	audio.offset = getKeyword("position");
 	audio.prefixdir = cp = getKeyword("prefix");
 
+	if(audio.offset && !*audio.offset)
+		audio.offset = NULL;
+
 	if(cp && !*cp)
 	{
 		cp = NULL;
@@ -1184,7 +1190,7 @@ const char *BayonneSession::getAudio(bool live)
 	}
 
 	cp = getKeyword("voice");
-	if(cp)
+	if(cp && *cp)
 	{
 		snprintf(bts, sizeof(bts), "%s", cp);
 		p = strchr(bts, '/');
