@@ -147,6 +147,8 @@ launch:
 			program = PYTHON_PROGRAM;
 		else if(!strcmp(ext, ".php"))
 			program = PHP_PROGRAM;
+		else if(!strcmp(ext, ".exe") || !strcmp(ext, ".il"))
+			program = PNET_PROGRAM;
 	}
 	ext = strrchr(argv[0], '-');
 	if(ext)
