@@ -631,13 +631,17 @@ bool Methods::scrLibexec(void)
 	if(sym)
 		clear(sym);
 
-	if(!BayonneSysexec::create(this))
-	{
-		error("libexec-failed");
-		return true;
-	}
-	state.lib = getLine();
-	setState(STATE_LIBEXEC);
+	state.wait.interval = 250;
+	cp = getKeyword("limit");
+	if(!cp)
+		cp = "0";
+	state.wait.count = atoi(cp);
+	state.wait.interval = getTimeoutKeyword("interval");
+
+	if(!state.wait.interval || state.wait.interval == TIMEOUT_INF)
+		state.wait.interval = 250;
+
+	setState(STATE_LIBWAIT);
 	return false;
 }
 
